@@ -1,5 +1,5 @@
 /*
- *   Copyright (C) 2007-2011 Tristan Heaven <tristanheaven@gmail.com>
+ *   Copyright (C) 2007-2013 Tristan Heaven <tristanheaven@gmail.com>
  *
  *   This file is part of GtkHash.
  *
@@ -33,22 +33,36 @@
 #include "prefs.h"
 
 static struct {
+	char *check;
 	char *datadir;
+	char *text;
 	char **files;
 	gboolean version;
 } opts = {
+	.check = NULL,
 	.datadir = NULL,
+	.text = NULL,
 	.files = NULL,
 	.version = false,
 };
 
 static void free_opts(void)
 {
+	if (opts.check) {
+		g_free(opts.check);
+		opts.check = NULL;
+	}
+
 	if (opts.datadir) {
 		g_free(opts.datadir);
 		opts.datadir = NULL;
 	}
 
+	if (opts.text) {
+		g_free(opts.text);
+		opts.text = NULL;
+	}
+
 	if (opts.files) {
 		g_strfreev(opts.files);
 		opts.files = NULL;
@@ -67,10 +81,18 @@ static char *filename_arg_to_uri(const char *arg)
 static void read_opts_preinit(int *argc, char ***argv)
 {
 	GOptionEntry entries[] = {
+		{
+			"check", 'c', 0, G_OPTION_ARG_STRING, &opts.check,
+			_("Check against the specified digest or checksum"), _("DIGEST")
+		},
 		{
 			"datadir", 'd', 0, G_OPTION_ARG_FILENAME, &opts.datadir,
 			_("Read program data from the specified directory"), _("DIRECTORY")
 		},
+		{
+			"text", 't', 0, G_OPTION_ARG_STRING, &opts.text,
+			_("Hash the specified text"), _("TEXT")
+		},
 		{
 			"version", 'v', 0, G_OPTION_ARG_NONE, &opts.version,
 			_("Show version information"), NULL
@@ -85,7 +107,7 @@ static void read_opts_preinit(int *argc, char ***argv)
 	GOptionContext *context = g_option_context_new(NULL);
 	GError *error = NULL;
 
-	g_atexit(free_opts);
+	atexit(free_opts);
 
 	g_option_context_add_main_entries(context, entries, GETTEXT_PACKAGE);
 	g_option_context_add_group(context, gtk_get_option_group(false));
@@ -123,6 +145,15 @@ static void read_opts_postinit(void)
 		g_slist_free_full(uris, g_free);
 	}
 
+	if (opts.check && *opts.check)
+		gui_add_check(opts.check);
+
+	if (opts.text && *opts.text) {
+		gui_add_text(opts.text);
+		if (!opts.files)
+			gui_set_view(GUI_VIEW_TEXT);
+	}
+
 	free_opts();
 }
 
@@ -134,23 +165,22 @@ int main(int argc, char **argv)
 	textdomain(GETTEXT_PACKAGE);
 #endif
 
-	g_thread_init(NULL);
 	gdk_threads_init();
 	gdk_threads_enter();
-	g_atexit(gdk_threads_leave);
+	atexit(gdk_threads_leave);
 
 	read_opts_preinit(&argc, &argv);
 
 	hash_init();
-	g_atexit(hash_deinit);
+	atexit(hash_deinit);
 
 	gui_init(opts.datadir ? opts.datadir : DATADIR);
-	g_atexit(gui_deinit);
+	atexit(gui_deinit);
 
 	list_init();
 
 	prefs_init();
-	g_atexit(prefs_deinit);
+	atexit(prefs_deinit);
 
 	read_opts_postinit();
 
